==> kassa-2.12.3.zip: app/models/messages.php <==
<?php
namespace Models;

// Модель с ошибками и сообщениями
class Messages {

	// данные о страницах
	function page_data($page) {
		$pages=array(
			'continue'=>array(
				'title'=>'Продолжить?',
				'inc'=>'messages_continue.htm'
			),
			'error'=>array(
				'title'=>'Возникла ошибка',
				'inc'=>'messages_error.htm'
			),
			'cd_error'=>array(
				'title'=>'Ошибка дисплея покупателя',
				'inc'=>'messages_cd_error.htm'
			),
			'scales_error'=>array(
				'title'=>'Ошибка весов',
				'inc'=>'messages_scales_error.htm'
			)
		);
		$pages[$page]['page']=$page;

		return $pages[$page];
	}

	function message($txt) {
		$inc=0;
		$incs=array(
			array('inc'=>'error.htm', 'title'=>'Ошибка'),
			array('inc'=>'message.htm', 'title'=>''),
		);
		$txts=array(
			'limited_version'=>array('txt'=>'Ограниченная версия', 'inc'=>0),
			'error'=>array('txt'=>'Неизвестная ошибка', 'inc'=>0),
			'i_am_teapot'=>array('txt'=>'Я чайник, а может быть кофейник, еще не определился', 'inc'=>0),
			'cashbox_users_not_found'=>array('txt'=>'В системе Агорта не указаны пользователи Кассы', 'inc'=>0),
			'db_error'=>array('txt'=>'Ошибка базы данных', 'inc'=>0),
			'save_usergroups_error'=>array('txt'=>'Ошибка при сохранении групп пользователей', 'inc'=>0),
			'save_users_error'=>array('txt'=>'Ошибка при сохранении пользователей', 'inc'=>0),
			'file_is_not_delete'=>array('txt'=>'Не удалось удалить файл', 'inc'=>0),
			'not_enough_data'=>array('txt'=>'Не хвататет данных', 'inc'=>0),
			'receipts_is_ready'=>array('txt'=>'<div class="page_reload">Возможно чек уже закрыт или перехвачен на другую кассу</div>', 'inc'=>0),
			'user_not_found'=>array('txt'=>'Пользователь не найден', 'inc'=>0),
			'pass_incorrect'=>array('txt'=>'Неверный пароль', 'inc'=>0),
			'autorization_is_already_done'=>array('txt'=>'Вход в данную учетную запись уже был выполнен.', 'inc'=>0),
			'access_closed'=>array('txt'=>'Доступ закрыт', 'inc'=>0),
			'not_found'=>array('txt'=>'Ничего не найдено', 'inc'=>0, 'close'=>true),
			'lines_not_found'=>array('txt'=>'В чеке нет товаров', 'inc'=>0, 'close'=>true),
			'document_is_closed'=>array('txt'=>'Нельзя вносить изменения в закрытый документ', 'inc'=>0, 'close'=>true),
			'position_is_already_in_progress'=>array('txt'=>'Позиция уже находится в работе', 'inc'=>0),
			'incorrect_data'=>array('txt'=>'Введено неверное значение', 'inc'=>0),
			'incorrect_select_discount'=>array('txt'=>'Неверное значение скидки', 'inc'=>0, 'close'=>true),
			'quantity_marked_goods_may_not_exceed_1'=>array('txt'=>'Количество штучного маркированного товара должно быть равно 1', 'inc'=>0),
			'quantity_error'=>array('txt'=>'Количество товара не может быть отрицательным', 'inc'=>0),
			'incorrect_email_or_phone'=>array('txt'=>'Некорректно введен e-mail (address@domen.ru) или телефон (+79110001122)', 'inc'=>0, 'close'=>true),
			'incorrect_auto_logout'=>array('txt'=>'Время автоматического выхода должно быть больше или равно 0', 'inc'=>0, 'close'=>true),
			'incorrect_egais_url'=>array('txt'=>'Укажите путь к Универсальному Транспортному Модулю ЕГАИС', 'inc'=>0, 'close'=>true),
			'input_organization_information'=>array('txt'=>'Укажите все необходимые данные об организации', 'inc'=>0, 'close'=>true),
			'no_synchronization_required'=>array('txt'=>'Синхронизация не требуется', 'inc'=>0),
			'sync_is_already_running'=>array('txt'=>'Синхронизация уже запущена', 'inc'=>0),
			'sync_is_running'=>array('txt'=>'Идет синхронизация кассы. Ждите.', 'inc'=>0),
			'kkm_is_not_activity'=>array('txt'=>'Работа с ККМ отключена в настройках', 'inc'=>0),
			'change_not_open'=>array('txt'=>'Нет открытых смен', 'inc'=>0),
			'change_open'=>array('txt'=>'Смена уже открыта', 'inc'=>0),
			'fr_only'=>array('txt'=>'Недоступно для установленного типа ККМ', 'inc'=>0),
			'vat_not_null'=>array('txt'=>'Номер налога не может быть равным 0', 'inc'=>0),
			'room_is_exists'=>array('txt'=>'Такой зал уже существует', 'inc'=>0),
			'room_is_not_empty'=>array('txt'=>'Зал не может быть удален, пока в нем установлены столы', 'inc'=>0),
			'place_taken'=>array('txt'=>'Это место уже занято', 'inc'=>0),
			'table_is_exists'=>array('txt'=>'Такой стол уже существует', 'inc'=>0),
			'table_is_not_empty'=>array('txt'=>'Стол не может быть удален, пока у него есть открытые чеки', 'inc'=>0),
			'workers_code_is_not_specified'=>array('txt'=>'Штрих-коды сотрудников не настроены', 'inc'=>0),
			'incorrect_workers_code'=>array('txt'=>'Штрих-код введен некорректно', 'inc'=>0, 'close'=>true),
			'product_stoped'=>array('txt'=>'Товар находится в стоп-листе', 'inc'=>0, 'close'=>true),
			'labeling_code_not_entered_into_circulation'=>array('txt'=>'Код маркировки не введен в оборот', 'inc'=>0, 'close'=>true),
			'products_did_not_pass_inspection'=>array('txt'=>'Продукция не прошла проверку', 'inc'=>0, 'close'=>true),
			'marking_code_already_added'=>array('txt'=>'Код маркировки уже добавлен в чек', 'inc'=>0),
			'mrc_error'=>array('txt'=>'Цена продажи больше максимальной розничной цены на упаковке', 'inc'=>0),
			'incorrect_price_with_buy_price'=>array('txt'=>'Цена продажи должна быть больше закупочной цены', 'inc'=>0),
			'incorrect_scales_url'=>array('txt'=>'Укажите путь к весам', 'inc'=>0),
			'free_sales_not_access'=>array('txt'=>'Свободная продажа запрещена', 'inc'=>0),
			'no_bonus_to_pay'=>array('txt'=>'Нет баллов для оплаты', 'inc'=>0),
			'productcategories_is_exists'=>array('txt'=>'Такая категория уже существует', 'inc'=>0),
			'productcategories_can_not_delete'=>array('txt'=>'Нельзя удалить непустую категорию', 'inc'=>0),
			'default_productcategories_can_not_change'=>array('txt'=>'Нельзя изменить эту категорию', 'inc'=>0),
			'not_delete_myself'=>array('txt'=>'Нельзя удалить самого себя', 'inc'=>0),
			'usergroups_can_not_delete'=>array('txt'=>'Нельзя удалить непустую группу пользователей', 'inc'=>0),
			'barcode_is_exists'=>array('txt'=>'Штрих код уже принадлежит другой номенклатуре', 'inc'=>0),
			'products_can_not_delete'=>array('txt'=>'Нельзя удалить номенклатуру, содержащуюся в открытом чеке', 'inc'=>0),
			'kitchen_printer_error'=>array('txt'=>'Ошибка при печати на кухонном принтере', 'inc'=>0),
			'bar_printer_error'=>array('txt'=>'Ошибка при печати на барном принтере', 'inc'=>0),
			'ttn_number_not_found'=>array('txt'=>'Не удается найти номер ТТН', 'inc'=>0),
			'ttn_not_found'=>array('txt'=>'Не удается найти ТТН', 'inc'=>0),
			'rests_not_found'=>array('txt'=>'Не найден ответ на запрос остатков на складе. Сначала сделайте запрос остатков и дождитесь ответа от ЕГАИС.', 'inc'=>0),
			'organization_not_found'=>array('txt'=>'Организация не найдена', 'inc'=>0),
			'identity_not_found'=>array('txt'=>'Невозможно определить идентификатор документа, возможно он отсутствует', 'inc'=>0),
			'epay_is_exists'=>array('txt'=>'Такой метод электронной оплаты уже существует', 'inc'=>0),
			'epay_not_found'=>array('txt'=>'Метод электронной оплаты не найден', 'inc'=>0),
			'selected_only_one'=>array('txt'=>'По умолчанию может быть выбран только один метод оплаты', 'inc'=>0),
			'combo_dont_work'=>array('txt'=>'В это время комбинация не доступна', 'inc'=>0),
			'its_combo'=>array('txt'=>'Нельзя вносить изменения в комбинацию', 'inc'=>0),
			'dont_change_payed_receipt'=>array('txt'=>'Этот чек уже оплачен, но не закрыт. Закройте чек.', 'inc'=>0),
			'close_all_receipts'=>array('txt'=>'Есть оплаченные и незакрытые чеки. Закройте все чеки.', 'inc'=>0),
			'expiration_date_error'=>array('txt'=>'Cрок годности истек', 'inc'=>0),
			'cyrilic_symbols_from_mark'=>array('txt'=>'В коде маркировки товара не могут быть кириллические символы. Проверьте расскладку клавиатуры.', 'inc'=>0),
			'license_has_expired'=>array('txt'=>'Срок лицензии истек', 'inc'=>0),
			'no_required_amount'=>array('txt'=>'Данного товара нет в необходимом количестве', 'inc'=>0),
			'not_printers'=>array('txt'=>'Невыбран принтер для печати', 'inc'=>0),
			'double_mark_found'=>array('txt'=>'Данная марка уже добавлена или была продана ранее', 'inc'=>0),
			'fn_closed'=>array('txt'=>'Архив ФН закрыт.', 'inc'=>0),
			'need_close_change'=>array('txt'=>'Необходимо закрыть смену.', 'inc'=>0),
			'need_set_ofd'=>array('txt'=>'Регистрация перерегистрация невозможна. Настройте ОФД.', 'inc'=>0),
			'fn_not_registr'=>array('txt'=>'ККТ незарегистрирована', 'inc'=>0),
			'full_version'=>array('txt'=>'Полная версия', 'inc'=>1),
			'loading'=>array('txt'=>'Загрузка...', 'inc'=>1),
			'login_successful'=>array('txt'=>'Авторизация прошла успешно', 'inc'=>1),
			'success'=>array('txt'=>'Успешно выполнено', 'inc'=>1),
			'logout_successful'=>array('txt'=>'Выход совершен', 'inc'=>1),
			'save_successful'=>array('txt'=>'Успешно сохранено', 'inc'=>1),
			'delete_successful'=>array('txt'=>'Успешно удалено', 'inc'=>1),
			'update'=>array('txt'=>'Обновлено '.date('d.m.Y H:i:s').'. Загрузка...', 'inc'=>1),
			'change_is_open'=>array('txt'=>'Смена открыта', 'inc'=>1),
			'change_is_close'=>array('txt'=>'Смена закрыта', 'inc'=>1),
			'x-report_is_ready'=>array('txt'=>'X-отчет сформирован', 'inc'=>1),
			'report_is_ready'=>array('txt'=>'Отчет сформирован', 'inc'=>1),
			'print_continue'=>array('txt'=>'Печать продолжена', 'inc'=>1),
			'request_has_been_sent'=>array('txt'=>'Запрос отправлен', 'inc'=>1),
			'ticket_reset'=>array('txt'=>'Чек аннулирован', 'inc'=>1),
			'success_products_synchronization'=>array('txt'=>'Товары и категории успешно синхронизированы', 'inc'=>1),
			'success_users_synchronization'=>array('txt'=>'Пользователи успешно синхронизированы', 'inc'=>1),
			'success_tickets_synchronization'=>array('txt'=>'Чеки успешно синхронизированы', 'inc'=>1),
			'success_partners_synchronization'=>array('txt'=>'Клиенты успешно синхронизированы', 'inc'=>1),
			'success_loyalty_synchronization'=>array('txt'=>'Программы лояльности успешно синхронизированы', 'inc'=>1),
			'successfully_added_fiscalization'=>array('txt'=>'Документы на фискализацию успешно добавлены', 'inc'=>1),
			'not_remote_fiscalization'=>array('txt'=>'Нет документов для удаленной фискализации', 'inc'=>1),
			'fiscalization_successful'=>array('txt'=>'Успешно фискализированно', 'inc'=>1),
			'successfully_synchronization_logs'=>array('txt'=>'Ошибки синхронизации успешно выгружены', 'inc'=>1),
			'successfully_synchronization'=>array('txt'=>'Синхронизация успешно завершена', 'inc'=>1),
			'request_is_sended'=>array('txt'=>'Запрос успешно отправлен. Ожидайте уведомления от ЕГАИС.', 'inc'=>1),
			'double_mark_not_found'=>array('txt'=>'Повторов маркировки не найдено', 'inc'=>1),
			'fn_closed_successful'=>array('txt'=>'Архив ФН успешно закрыт', 'inc'=>1),
		);

		if(isset($txts[$txt])) {
			$inc=$txts[$txt]['inc'];
			$close=$txts[$txt]['close'];
			$txt=$txts[$txt]['txt'];
		}

		return array(
			'txt'=>$txt,
			'title'=>$incs[$inc]['title'],
			'inc'=>$incs[$inc]['inc'],
			'close'=>$close
		);
	}
}

==> kassa-2.12.26.zip: app/models/messages.php <==
<?php
namespace Models;

// Модель с ошибками и сообщениями
class Messages {

	// данные о страницах
	function page_data($page) {
		$pages=array(
			'continue'=>array(
				'title'=>'Продолжить?',
				'inc'=>'messages_continue.htm'
			),
			'error'=>array(
				'title'=>'Возникла ошибка',
				'inc'=>'messages_error.htm'
			),
			'cd_error'=>array(
				'title'=>'Ошибка дисплея покупателя',
				'inc'=>'messages_cd_error.htm'
			),
			'scales_error'=>array(
				'title'=>'Ошибка весов',
				'inc'=>'messages_scales_error.htm'
			)
		);
		$pages[$page]['page']=$page;

		return $pages[$page];
	}

	function message($txt) {
		$inc=0;
		$incs=array(
			array('inc'=>'error.htm', 'title'=>'Ошибка'),
			array('inc'=>'message.htm', 'title'=>''),
		);
		$txts=array(
			'limited_version'=>array('txt'=>'Ограниченная версия', 'inc'=>0),
			'error'=>array('txt'=>'Неизвестная ошибка', 'inc'=>0),
			'i_am_teapot'=>array('txt'=>'Я чайник, а может быть кофейник, еще не определился', 'inc'=>0),
			'cashbox_users_not_found'=>array('txt'=>'В системе Агорта не указаны пользователи Кассы', 'inc'=>0),
			'db_error'=>array('txt'=>'Ошибка базы данных', 'inc'=>0),
			'save_usergroups_error'=>array('txt'=>'Ошибка при сохранении групп пользователей', 'inc'=>0),
			'save_users_error'=>array('txt'=>'Ошибка при сохранении пользователей', 'inc'=>0),
			'file_is_not_delete'=>array('txt'=>'Не удалось удалить файл', 'inc'=>0),
			'not_enough_data'=>array('txt'=>'Не хвататет данных', 'inc'=>0),
			'receipts_is_ready'=>array('txt'=>'<div class="page_reload">Возможно чек уже закрыт или перехвачен на другую кассу</div>', 'inc'=>0),
			'user_not_found'=>array('txt'=>'Пользователь не найден', 'inc'=>0),
			'pass_incorrect'=>array('txt'=>'Неверный пароль', 'inc'=>0),
			'autorization_is_already_done'=>array('txt'=>'Вход в данную учетную запись уже был выполнен.', 'inc'=>0),
			'access_closed'=>array('txt'=>'Доступ закрыт', 'inc'=>0),
			'not_found'=>array('txt'=>'Ничего не найдено', 'inc'=>0, 'close'=>true),
			'lines_not_found'=>array('txt'=>'В чеке нет товаров', 'inc'=>0, 'close'=>true),
			'document_is_closed'=>array('txt'=>'Нельзя вносить изменения в закрытый документ', 'inc'=>0, 'close'=>true),
			'position_is_already_in_progress'=>array('txt'=>'Позиция уже находится в работе', 'inc'=>0),
			'incorrect_data'=>array('txt'=>'Введено неверное значение', 'inc'=>0),
			'incorrect_select_discount'=>array('txt'=>'Неверное значение скидки', 'inc'=>0, 'close'=>true),
			'quantity_marked_goods_may_not_exceed_1'=>array('txt'=>'Количество штучного маркированного товара должно быть равно 1', 'inc'=>0),
			'invalid_mark'=>array('txt'=>'При сканировании марки, возможно возникли ошибки. Попробуйте еще раз.', 'inc'=>0),
			'quantity_error'=>array('txt'=>'Количество товара не может быть отрицательным', 'inc'=>0),
			'lines_with_count_0'=>array('txt'=>'В чеке есть товары с количеством равным 0', 'inc'=>0),
			'quantity_error_or_0'=>array('txt'=>'Количество товара не может быть отрицательным или равным 0', 'inc'=>0),
			'error_change_modifikation'=>array('txt'=>'Нельзя менять цену и количество данного модификатора', 'inc'=>0),
			'incorrect_email_or_phone'=>array('txt'=>'Некорректно введен e-mail (address@domen.ru) или телефон (+79110001122)', 'inc'=>0, 'close'=>true),
			'incorrect_auto_logout'=>array('txt'=>'Время автоматического выхода должно быть больше или равно 0', 'inc'=>0, 'close'=>true),
			'incorrect_egais_url'=>array('txt'=>'Укажите путь к Универсальному Транспортному Модулю ЕГАИС', 'inc'=>0, 'close'=>true),
			'input_organization_information'=>array('txt'=>'Укажите все необходимые данные об организации', 'inc'=>0, 'close'=>true),
			'no_synchronization_required'=>array('txt'=>'Синхронизация не требуется', 'inc'=>0),
			'sync_is_already_running'=>array('txt'=>'Синхронизация уже запущена', 'inc'=>0),
			'sync_is_running'=>array('txt'=>'Идет синхронизация кассы. Ждите.', 'inc'=>0),
			'kkm_is_not_activity'=>array('txt'=>'Работа с ККМ отключена в настройках', 'inc'=>0),
			'change_not_open'=>array('txt'=>'Нет открытых смен', 'inc'=>0),
			'change_open'=>array('txt'=>'Смена уже открыта', 'inc'=>0),
			'fr_only'=>array('txt'=>'Недоступно для установленного типа ККМ', 'inc'=>0),
			'vat_not_null'=>array('txt'=>'Номер налога не может быть равным 0', 'inc'=>0),
			'room_is_exists'=>array('txt'=>'Такой зал уже существует', 'inc'=>0),
			'room_is_not_empty'=>array('txt'=>'Зал не может быть удален, пока в нем установлены столы', 'inc'=>0),
			'place_taken'=>array('txt'=>'Это место уже занято', 'inc'=>0),
			'table_is_exists'=>array('txt'=>'Такой стол уже существует', 'inc'=>0),
			'table_is_not_empty'=>array('txt'=>'Стол не может быть удален, пока у него есть открытые чеки', 'inc'=>0),
			'workers_code_is_not_specified'=>array('txt'=>'Штрих-коды сотрудников не настроены', 'inc'=>0),
			'incorrect_workers_code'=>array('txt'=>'Штрих-код введен некорректно', 'inc'=>0, 'close'=>true),
			'product_stoped'=>array('txt'=>'Товар находится в стоп-листе', 'inc'=>0, 'close'=>true),
			'labeling_code_not_entered_into_circulation'=>array('txt'=>'Код маркировки не введен в оборот', 'inc'=>0, 'close'=>true),
			'products_did_not_pass_inspection'=>array('txt'=>'Продукция не прошла проверку', 'inc'=>0, 'close'=>true),
			'marking_code_already_added'=>array('txt'=>'Код маркировки уже добавлен в чек', 'inc'=>0),
			'mrc_error'=>array('txt'=>'Цена продажи больше максимальной розничной цены на упаковке', 'inc'=>0),
			'incorrect_price_with_buy_price'=>array('txt'=>'Цена продажи должна быть больше закупочной цены', 'inc'=>0),
			'incorrect_scales_url'=>array('txt'=>'Укажите путь к весам', 'inc'=>0),
			'free_sales_not_access'=>array('txt'=>'Свободная продажа запрещена', 'inc'=>0),
			'no_bonus_to_pay'=>array('txt'=>'Нет баллов для оплаты', 'inc'=>0),
			'productcategories_is_exists'=>array('txt'=>'Такая категория уже существует', 'inc'=>0),
			'productcategories_can_not_delete'=>array('txt'=>'Нельзя удалить непустую категорию', 'inc'=>0),
			'default_productcategories_can_not_change'=>array('txt'=>'Нельзя изменить эту категорию', 'inc'=>0),
			'not_delete_myself'=>array('txt'=>'Нельзя удалить самого себя', 'inc'=>0),
			'usergroups_can_not_delete'=>array('txt'=>'Нельзя удалить непустую группу пользователей', 'inc'=>0),
			'barcode_is_exists'=>array('txt'=>'Штрих код уже принадлежит другой номенклатуре', 'inc'=>0),
			'products_can_not_delete'=>array('txt'=>'Нельзя удалить номенклатуру, содержащуюся в открытом чеке', 'inc'=>0),
			'kitchen_printer_error'=>array('txt'=>'Ошибка при печати на кухонном принтере', 'inc'=>0),
			'bar_printer_error'=>array('txt'=>'Ошибка при печати на барном принтере', 'inc'=>0),
			'ttn_number_not_found'=>array('txt'=>'Не удается найти номер ТТН', 'inc'=>0),
			'ttn_not_found'=>array('txt'=>'Не удается найти ТТН', 'inc'=>0),
			'rests_not_found'=>array('txt'=>'Не найден ответ на запрос остатков на складе. Сначала сделайте запрос остатков и дождитесь ответа от ЕГАИС.', 'inc'=>0),
			'organization_not_found'=>array('txt'=>'Организация не найдена', 'inc'=>0),
			'identity_not_found'=>array('txt'=>'Невозможно определить идентификатор документа, возможно он отсутствует', 'inc'=>0),
			'epay_is_exists'=>array('txt'=>'Такой метод электронной оплаты уже существует', 'inc'=>0),
			'epay_not_found'=>array('txt'=>'Метод электронной оплаты не найден', 'inc'=>0),
			'selected_only_one'=>array('txt'=>'По умолчанию может быть выбран только один метод оплаты', 'inc'=>0),
			'combo_dont_work'=>array('txt'=>'В это время комбинация не доступна', 'inc'=>0),
			'its_combo'=>array('txt'=>'Нельзя вносить изменения в комбинацию', 'inc'=>0),
			'dont_change_payed_receipt'=>array('txt'=>'Этот чек уже оплачен, но не закрыт. Закройте чек.', 'inc'=>0),
			'close_all_receipts'=>array('txt'=>'Есть оплаченные и незакрытые чеки. Закройте все чеки.', 'inc'=>0),
			'expiration_date_error'=>array('txt'=>'Cрок годности истек', 'inc'=>0),
			'cyrilic_symbols_from_mark'=>array('txt'=>'В коде маркировки товара не могут быть кириллические символы. Проверьте расскладку клавиатуры.', 'inc'=>0),
			'license_has_expired'=>array('txt'=>'Срок лицензии истек', 'inc'=>0),
			'no_required_amount'=>array('txt'=>'Данного товара нет в необходимом количестве', 'inc'=>0),
			'not_printers'=>array('txt'=>'Невыбран принтер для печати', 'inc'=>0),
			'double_mark_found'=>array('txt'=>'Данная марка уже добавлена или была продана ранее', 'inc'=>0),
			'fn_closed'=>array('txt'=>'Архив ФН закрыт.', 'inc'=>0),
			'need_close_change'=>array('txt'=>'Необходимо закрыть смену.', 'inc'=>0),
			'need_set_ofd'=>array('txt'=>'Регистрация перерегистрация невозможна. Настройте ОФД.', 'inc'=>0),
			'fn_not_registr'=>array('txt'=>'ККТ незарегистрирована', 'inc'=>0),
			'full_version'=>array('txt'=>'Полная версия', 'inc'=>1),
			'loading'=>array('txt'=>'Загрузка...', 'inc'=>1),
			'login_successful'=>array('txt'=>'Авторизация прошла успешно', 'inc'=>1),
			'success'=>array('txt'=>'Успешно выполнено', 'inc'=>1),
			'logout_successful'=>array('txt'=>'Выход совершен', 'inc'=>1),
			'save_successful'=>array('txt'=>'Успешно сохранено', 'inc'=>1),
			'delete_successful'=>array('txt'=>'Успешно удалено', 'inc'=>1),
			'update'=>array('txt'=>'Обновлено '.date('d.m.Y H:i:s').'. Загрузка...', 'inc'=>1),
			'change_is_open'=>array('txt'=>'Смена открыта', 'inc'=>1),
			'change_is_close'=>array('txt'=>'Смена закрыта', 'inc'=>1),
			'x-report_is_ready'=>array('txt'=>'X-отчет сформирован', 'inc'=>1),
			'report_is_ready'=>array('txt'=>'Отчет сформирован', 'inc'=>1),
			'print_continue'=>array('txt'=>'Печать продолжена', 'inc'=>1),
			'request_has_been_sent'=>array('txt'=>'Запрос отправлен', 'inc'=>1),
			'ticket_reset'=>array('txt'=>'Чек аннулирован', 'inc'=>1),
			'success_products_synchronization'=>array('txt'=>'Товары и категории успешно синхронизированы', 'inc'=>1),
			'success_users_synchronization'=>array('txt'=>'Пользователи успешно синхронизированы', 'inc'=>1),
			'success_tickets_synchronization'=>array('txt'=>'Чеки успешно синхронизированы', 'inc'=>1),
			'success_partners_synchronization'=>array('txt'=>'Клиенты успешно синхронизированы', 'inc'=>1),
			'success_loyalty_synchronization'=>array('txt'=>'Программы лояльности успешно синхронизированы', 'inc'=>1),
			'successfully_added_fiscalization'=>array('txt'=>'Документы на фискализацию успешно добавлены', 'inc'=>1),
			'not_remote_fiscalization'=>array('txt'=>'Нет документов для удаленной фискализации', 'inc'=>1),
			'fiscalization_successful'=>array('txt'=>'Успешно фискализированно', 'inc'=>1),
			'successfully_synchronization_logs'=>array('txt'=>'Ошибки синхронизации успешно выгружены', 'inc'=>1),
			'successfully_synchronization'=>array('txt'=>'Синхронизация успешно завершена', 'inc'=>1),
			'request_is_sended'=>array('txt'=>'Запрос успешно отправлен. Ожидайте уведомления от ЕГАИС.', 'inc'=>1),
			'double_mark_not_found'=>array('txt'=>'Повторов маркировки не найдено', 'inc'=>1),
			'fn_closed_successful'=>array('txt'=>'Архив ФН успешно закрыт', 'inc'=>1),
		);

		if(isset($txts[$txt])) {
			$inc=$txts[$txt]['inc'];
			$close=$txts[$txt]['close'];
			$txt=$txts[$txt]['txt'];
		}

		return array(
			'txt'=>$txt,
			'title'=>$incs[$inc]['title'],
			'inc'=>$incs[$inc]['inc'],
			'close'=>$close
		);
	}
}
